@@ -7,8 +7,8 @@ from typing import Callable
 from typing import Iterable
 from typing import List
 from typing import NamedTuple
+from typing import Protocol
 from typing import Tuple
-from typing import TYPE_CHECKING
 from typing import TypeVar
 
 from tokenize_rt import Offset
@@ -16,11 +16,6 @@ from tokenize_rt import Token
 
 from pyupgrade import _plugins
 
-if TYPE_CHECKING:
-    from typing import Protocol
-else:
-    Protocol = object
-
 Version = Tuple[int, ...]
 
 
